# Acrresolv
Small and stupid acronym resolver

## Usage

```python
from acrresolv import resolve

resolve("central processing unit")
# "CPU"
```

Eventually, this will be upgraded to a big and not stupid acronym resolver using sckit-learn